from microservice_template_core import Core
from microservice_template_core.settings import ServiceConfig, FlaskConfig, DbConfig, LoggerConfig
from harp_gate_client.endpoints.notifications import ns as notifications
from apscheduler.schedulers.background import BackgroundScheduler
from pytz import utc
from harp_gate_client.notifications_collectors.push_notification import notification_scraper
import harp_gate_client.settings as settings


def schedule_jobs():
    # https://apscheduler.readthedocs.io/en/stable/userguide.html?highlight=max_instances#limiting-the-number-of-concurrently-executing-instances-of-a-job
    scheduler = BackgroundScheduler({'apscheduler.job_defaults.max_instances': '1'})
    scheduler.configure(timezone=utc)
    scheduler.start()
    scheduler.add_job(notification_scraper, args=['icinga'], trigger='interval', seconds=settings.NOTIFICATIONS_SCRAPE_INTERVAL_SECONDS)
    scheduler.add_job(notification_scraper, args=['zabbix'], trigger='interval', seconds=settings.NOTIFICATIONS_SCRAPE_INTERVAL_SECONDS)


def main():
    ServiceConfig.configuration['namespaces'] = [notifications]
    FlaskConfig.FLASK_DEBUG = False
    DbConfig.USE_DB = False
    ServiceConfig.SERVICE_PORT = 8082  # Only for test
    app = Core()
    app.run()


if __name__ == '__main__':
    schedule_jobs()
    main()




import requests
import json
import traceback
import harp_gate_client.settings as settings
from microservice_template_core.tools.logger import get_logger
import urllib3

logger = get_logger()
urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)


class ZabbixCollector(object):
    def __init__(self, ms_source, event_id):
        self.ms_source = ms_source
        self.alerts_count = 0
        self.event_id = event_id
        self.headers = {
            'Content-Type': 'application/json-rpc'
        }

    def ms_notification_output(self, result_body):
        output = {
            'host.name': result_body['hosts'][0]['name'],
            'item.value1': result_body['value'],
            'item.key1': '',  # Don`t present
            'trigger.severity': result_body['priority'],
            'trigger.name': result_body['description'],
            'trigger.expression': result_body['expression'],
            'source': self.ms_source,
            'trigger.description': '',  # Don`t present
            'item.id1': result_body['items'][0]['itemid'],
            'trigger.url': result_body['url'],
            'triggerid': result_body['triggerid'],
            'trigger.hostgroup.name': '',  # Don`t present
            'trigger.status': 'PROBLEM'
        }

        return output

    @staticmethod
    def ms_unique_name(result_body):
        unique_name = f"other:::{result_body['hosts'][0]['name']}:::{result_body['description']}"

        return unique_name

    def zabbix_auth(self):
        auth_json = {
            "jsonrpc": "2.0",
            "method": "user.login",
            "params": {
                "user": settings.ZABBIX_API_USER,
                "password": settings.ZABBIX_API_PASS
            },
            "id": 1,
            "auth": None
        }

        auth = requests.post(
            url=f"{self.ms_source}/api_jsonrpc.php",
            headers=self.headers,
            data=json.dumps(auth_json),
            timeout=5
        ).json()

        if 'result' in auth:
            auth = auth['result']

        logger.info(
            msg=f"Successfully logged into Zabbix: {auth}",
            extra={'tags': {'event_id': str(self.event_id)}}
        )

        return auth

    def collect_triggers(self):
        data = {
            "jsonrpc": "2.0",
            "method": "trigger.get",
            "params": {
                "output": ['description', 'priority', 'value', 'expression', 'url'],
                "filter": {
                    "value": 1,
                    "status": 0
                },
                "state": 0,
                "active": True,
                "withLastEventUnacknowledged": True,
                "expandDescription": 1,
                "expandExpression": 1,
                "expandComment": 1,
                "selectHosts": ["name"],
                "selectItems": ["item"],
                "selectGroups": ["group"]
            },
            "auth": self.zabbix_auth(),
            "id": 1
        }

        result = requests.post(
            url=f"{self.ms_source}/api_jsonrpc.php",
            headers=self.headers,
            data=json.dumps(data)
        ).json()

        logger.info(
            msg=f"Collected triggers from Zabbix:\n{result}",
            extra={'tags': {'event_id': str(self.event_id)}}
        )

        return result

    def process_result(self):
        alerts_per_host = {}
        result = self.collect_triggers()

        if 'result' in result:
            for trigger in result['result']:
                notification_body = self.ms_notification_output(result_body=trigger)
                ms_unique_name = self.ms_unique_name(result_body=trigger)
                alerts_per_host[ms_unique_name] = notification_body
                self.alerts_count += 1

        return alerts_per_host, self.alerts_count

    def main(self):
        return self.process_result()






import click


@click.command()
@click.option("--count", default=1, help="Number of greetings.")
@click.option("--name", prompt="Your name", help="The person to greet.")
def hello(count, name):
    """Simple program that greets NAME for a total of COUNT times."""
    for _ in range(count):
        click.echo(f"Hello, {name}!")


def main():
    hello()


if __name__ == '__main__':
    main()



import os

# Icinga settings
ICINGA_API_USER = os.getenv('ICINGA_API_USER', 'root')
ICINGA_API_PASS = os.getenv('ICINGA_API_PASS', 'd0c87be02fdb79f0')

# Zabbix settings
ZABBIX_API_USER = os.getenv('ZABBIX_API_USER', 'Admin')
ZABBIX_API_PASS = os.getenv('ZABBIX_API_PASS', 'zabbix')

# General settings
NOTIFICATIONS_SCRAPE_INTERVAL_SECONDS = os.getenv('NOTIFICATIONS_SCRAPE_INTERVAL', 5)

# Collector settings
GATE_HOST = os.getenv('GATE_HOST', 'http://127.0.0.1:8081/api/v1/gate-collector')

# Temp MS settings
ZABBIX_SYSTEMS = [
    "http://127.0.0.1:8084"
]

ICINGA_SYSTEMS = [
    "127.0.0.1"
]

# LOCATIONS = {
#     "zabbix": {
#         "zabbix.aws": "http://127.0.0.1:8084/api_jsonrpc.php"
#     },
#     "icinga": {
#         "icinga.aws": "127.0.0.1"
#     }
# }





from setuptools import setup, find_packages
import os
import pwd
import grp
import sys
from setuptools import Command
SERVICE_NAME = 'harp-gate-client'
SERVICE_NAME_NORMALIZED = SERVICE_NAME.replace('-', '_')

print("sys.version_info: ", sys.version_info)

# if sys.version_info < (3,7):
#     sys.exit('Sorry, Python < 3.7 is not supported')


with open('requirements.txt') as f:
    requirements = f.read().splitlines()


def change_fcgi_permissions(files=None, folders=None):
    if files:
        for file in files:
            os.chmod(file, 0o755)
    if folders:
        for folder in folders:
            os.chmod(folder, 0o655)


def create_folders():
    pass
    # directories = [f'/opt/{SERVICE_NAME_NORMALIZED}', f'/opt/fcgi', f'/var/log/{SERVICE_NAME_NORMALIZED}']
    # uid = pwd.getpwnam("root").pw_uid
    # gid = grp.getgrnam("root").gr_gid
    # for directory in directories:
    #     if not os.path.exists(directory):
    #         os.makedirs(directory)
    #         os.chown(directory, uid, gid)


class CustomInstallCommand(Command):
    user_options = []

    def initialize_options(self):
        """Abstract method that is required to be overwritten"""

    def finalize_options(self):
        """Abstract method that is required to be overwritten"""

    def run(self):
        create_folders()
        # change_fcgi_permissions([],
        #                         [f'/opt/fcgi/'])


tests_require = ['test'],

setup(
    name=SERVICE_NAME,
    python_requires='>3.7.0',
    version='1.0.4',
    description="Harp Gate Client",
    url='',
    include_package_data=True,
    author='',
    author_email='',
    classifiers=[
    ],
    keywords=[],
    packages=find_packages(),
    install_requires=requirements,
    tests_require=tests_require,
    entry_points={
        'console_scripts': [
            f'{SERVICE_NAME} = {SERVICE_NAME_NORMALIZED}.app:main',
            f'harp-agent = cmd_command.test_commands:main',
        ]
    },
    zip_safe=False,
    cmdclass={
        'configure': CustomInstallCommand,
    },
    data_files=[]
)
